/*
 * (C) Copyright Architecture and Language Implementation Laboratory,
 * Department of Computer Science,
 * University of Massachusetts at Amherst. 2001
 * All rights reserved.
 */

package com.ibm.JikesRVM;

import java.util.List;
import com.ibm.JikesRVM.adaptive.VM_Controller;

/**
 * Utilities for providing compiler advice.  Advice files provided
 * at run time allow compilers to be specified for particular methods
 * <p>
 * <i>Run time</i> advice is given by identifying an advice file
 * through a command line option:
 * <code>-X:aos:compiler_advice_file=path-to-advice-file</code>.
 *
 * @author Chris Hoffmann
 * @author <a href="http://cs.anu.edu.au/~Steve.Blackburn">Steve Blackburn</a>
 * @version $Revision: 1.1 $
 * @date    $Date: 2004/09/07 13:42:44 $ 
 *
 * @see VM_CompilerAdviceAttribute
 * @see VM_CompilerAdviceInfoReader
 * @see VM_RuntimeCompiler 
 */
class VM_CompilerAdvice  {
  
  /**
   *  Read a list of compiler advice annotations from a file
   */
  public static void postBoot() {
    VM_CompilerAdviceAttribute.postBoot();
    String compilerAdviceFileName = VM_Controller.options.COMPILER_ADVICE_FILE;
    if ((compilerAdviceFileName != null) && 
        (compilerAdviceFileName.length() > 0)) {
      VM.sysWrite("Compiler advice file name ");
      VM.sysWriteln(compilerAdviceFileName);
      List compilerAdviceInfoList = 
        VM_CompilerAdviceInfoReader.readCompilerAdviceFile(
          compilerAdviceFileName);
      // register these sites so that when a compilation is done,
      // these sites use compiler advice
      VM_CompilerAdviceAttribute.registerCompilerAdvice(compilerAdviceInfoList);
    }
  }
}
